@@ -1,7 +1,7 @@
 function cardElement (element) {
 	return `<li>${element.count} <span class="card" scryfallId="${element.id}" data-tippy-content="
 		<div class='card-container'>
-			<img data-src='https://api.scryfall.com/cards/${element.id}?format=image' src='https://api.scryfall.com/cards/${element.id}?format=image' class='card-image'>
+			<img data-src='https://api.scryfall.com/cards/${element.id}?format=image' class='card-image'>
 		</div>" >${element.name}</span></li>`
 }
 
